@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.5.0
+# @version 2.5.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -43,7 +43,8 @@ class Framework:
     plasmalib    = ""                        # plasma library
     plasmaurl    = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/plasma.tar.gz"
     urlbase      = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs"
-    versions     = ("2.5.0b1", "2.4.6", "2.4.5", "2.4.2", "2.4.1", "2.4.0",
+    versions     = ("2.5.1", "2.5.0b1",
+                    "2.4.6", "2.4.5", "2.4.2", "2.4.1", "2.4.0",
                     "2.3.1", "2.3.0",
                     "2.2.0", "2.1.0",
                     "2.0.0",
@@ -656,18 +657,23 @@ You can specify it using the --fc flag."""
             self.config.ld_fcmain   = ' -Mnomain'
             self.testing = 0; # Cannot compile lintest with fc_main option
         else:
+            self.config.compiler = "Unknown"
             print 'unknown'
 
         print 'Detecting C compiler...',
         if self.cc_is_intel():
+            self.config.compiler = "Intel"
             self.config.ccflags    += ' -diag-disable vec'
             print 'Intel'
         elif self.cc_is_gnu():
+            self.config.compiler = "GNU"
             print 'GNU'
         elif self.cc_is_xlc():
+            self.config.compiler = "XLC"
             self.config.ccflags    += ' -qstrict -qthreaded'
             print 'IBM'
         elif self.cc_is_pgi():
+            self.config.compiler = "PGI"
             print 'PGI'
         else:
             print 'unknown'
@@ -690,9 +696,9 @@ You can specify it using the --fc flag."""
 
 
     def fc_is_gnu(self):
-        comm = self.config.fc+' --help'
+        comm = self.config.fc+' -v'
         (output, error, retz) = runShellCommand(comm)
-        isifort = string.find(output,'gnu.org')
+        isifort = string.find(error,'gcc')
         if isifort != -1:
             return 1
 
@@ -739,11 +745,10 @@ You can specify it using the --fc flag."""
 
         return 0
 
-
     def cc_is_gnu(self):
-        comm = self.config.cc+' --help'
+        comm = self.config.cc+' -v'
         (output, error, retz) = runShellCommand(comm)
-        isifort = string.find(output,'gnu.org')
+        isifort = string.find(error,'gcc')
         if isifort != -1:
             return 1
 
