@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.5.0
+# @version 2.5.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -247,7 +247,7 @@ LAPACKELIB   = liblapacke.a
         # compile and generate library
         print 'Compile and generate reference LAPACK C interface...',
         sys.stdout.flush()
-        comm = self.make+' lapackelib'
+        comm = self.make+' -j 4 lapackelib'
         (output, error, retz) = runShellCommand(comm)
         if retz:
             print "\n\nLAPCWRAPPER: cannot compile LAPACK C interface"
