@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.5.0
+# @version 2.5.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -98,6 +98,13 @@ LIB           = -lplasma -lcoreblas -lcorelapack -lcblas $(LIBBLAS) -lpthread -l
 #//////////////////////////////////////////////////////////////////////////
 """
         else:
+            if self.config.blasname == "mkl":
+                if self.config.compiler == "GNU" or self.config.compiler == "Intel":
+                    self.config.ccflags += " -DPLASMA_WITH_MKL"
+            elif self.config.blasname == "acml":
+                if self.config.compiler == "GNU" or self.config.compiler == "Intel":
+                    self.config.ccflags += " -DPLASMA_WITH_ACML"
+
             makeinc ="""
 #/////////////////// P /// L /// A /// S /// M /// A //////////////////
 #/// PLASMA is a software package provided by Univ. of Tennessee,  ///
