@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.5.0
+# @version 2.5.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -22,7 +22,6 @@ import shutil
 import framework
 
 class Tmg(framework.Framework):
-    lapackurl = "http://www.netlib.org/lapack/lapack.tgz"
 
     """ This class takes care of the libtmg from LAPACK installation. """
     def __init__(self, config, plasma):
@@ -34,6 +33,8 @@ class Tmg(framework.Framework):
         self.downcmd = plasma.downcmd
         self.prefix  = plasma.prefix
         self.plasma  = plasma
+        self.lapversion = plasma.lapversion
+        self.lapackurl  = "http://www.netlib.org/lapack/"+self.lapversion+".tgz"
 
         if self.plasma.downtmg:
             print "The netlib LAPACK will be downloaded to install libtmg.a"
@@ -134,24 +135,24 @@ The libtmg from reference LAPACK library is being installed.
 
         # unzip and untar
         print 'Unzip and untar reference BLAS...',
-        comm = 'gunzip -f lapack.tgz'
+        comm = 'gunzip -f '+self.lapversion+'.tgz'
         (output, error, retz) = runShellCommand(comm)
         if retz:
-            print '\n\nlibtmg: cannot unzip lapack.tgz'
+            print '\n\nlibtmg: cannot unzip '+self.lapversion+'.tgz'
             print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
             sys.exit()
 
-        comm = 'tar xf lapack.tar'
+        comm = 'tar xf '+self.lapversion+'.tar'
         (output, error, retz) = runShellCommand(comm)
         if retz:
-            print '\n\nlibtmg: cannot untar lapack.tgz'
+            print '\n\nlibtmg: cannot untar '+self.lapversion+'.tar'
             print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
             sys.exit()
-        os.remove('lapack.tar')
+        os.remove(self.lapversion+'.tar')
         print 'done'
 
         # change to BLAS dir
-        os.chdir(os.path.join(os.getcwd(),'lapack-3.3.1'))
+        os.chdir(os.path.join(os.getcwd(), self.lapversion))
 
         # Write Makefile.in
         writefile('make.inc', """
