@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.5.0
+# @version 2.5.1
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -18,9 +18,7 @@
 import os
 import re
 import shutil
-
-import popen2
-
+import subprocess
 import select
 
 
@@ -55,46 +53,12 @@ class NullFile:
 
 def runShellCommand(command, outfile=None):
     """ runs a shell command """
-
-    ret        = None
-    out        = ''
-    err        = ''
-
     if not outfile:
       outfile = NullFile()
 
-    (input, output, error, pipe) = openPipe(command)
-    input.close()
-    outputClosed = 0
-    errorClosed  = 0
-    lst = [output, error]
-    while 1:
-      ready = select.select(lst, [], [])
-      if len(ready[0]):
-        if error in ready[0]:
-          msg = error.readline()
-          if msg:
-            err += msg
-          else:
-            errorClosed = 1
-            lst.remove(error)
-        if output in ready[0]:
-          msg = output.readline()
-          if msg:
-            out += msg
-	    outfile.write(msg)
-	    outfile.flush()
-          else:
-            outputClosed = 1
-            lst.remove(output)
-      if outputClosed and errorClosed:
-        break
-    output.close()
-    error.close()
-    if pipe:
-      ret = pipe.wait()
-    return (out, err, ret)
-
+    proc = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    (out, err) = proc.communicate()
+    return (out, err, proc.returncode)
 
 def getURLName(url):
     directory=os.curdir
